using System;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Net.Http;
using System.Text;
using EtherealEngine.Models;
using Hardcodet.Wpf.TaskbarNotification;
using Newtonsoft.Json;

namespace EtherealEngine.Services;

public class DiscordWebhooks
{
	private readonly Configuration config = new Configuration();

	private string lastCrashContent = "";

	public async void CrashReport()
	{
		_ = 1;
		try
		{
			if (!File.Exists("C:\\Ethereal\\crash_info.txt") || !File.Exists("C:\\Ethereal\\Ethereal.log") || string.IsNullOrEmpty(Settings.Default.crashWebhookUri))
			{
				return;
			}
			string text = await File.ReadAllTextAsync("C:\\Ethereal\\Ethereal.log");
			if (!text.Contains("FATAL EXCEPTION RECEIVED") || !(text != lastCrashContent))
			{
				return;
			}
			string text2 = Convert.ToBase64String(Guid.NewGuid().ToByteArray()).Substring(0, 10);
			TaskbarIcon taskbarIcon = new TaskbarIcon();
			taskbarIcon.Icon = Icon.ExtractAssociatedIcon("Images/Brand/logo.ico");
			taskbarIcon.ShowBalloonTip("Info", "Crash report has been sent to developers. (ID: " + text2 + ")", BalloonIcon.Info);
			string crashContent = string.Empty;
			using (StreamReader streamReader = new StreamReader(new FileStream("C:\\Ethereal\\crash_info.txt", FileMode.Open, FileAccess.Read, FileShare.ReadWrite)))
			{
				crashContent = streamReader.ReadToEnd();
			}
			StringBuilder stringBuilder = new StringBuilder();
			using (StreamReader streamReader2 = new StreamReader(new FileStream("C:\\Ethereal\\Ethereal.log", FileMode.Open, FileAccess.Read, FileShare.ReadWrite)))
			{
				int num = 0;
				int num2 = File.ReadLines("C:\\Ethereal\\Ethereal.log").Count();
				while (!streamReader2.EndOfStream)
				{
					string value = streamReader2.ReadLine();
					if (!string.IsNullOrEmpty(value) && num2 - 60 <= num)
					{
						stringBuilder.AppendLine(value);
					}
					num++;
				}
			}
			StringContent content = new StringContent(JsonConvert.SerializeObject(new
			{
				password = Xor.EncryptOrDecrypt("EtherealKey420"),
				username = Settings.Default.username,
				crashContent = crashContent,
				etherealLog1 = stringBuilder.ToString(),
				crashId = text2
			}).ToString(), Encoding.UTF8, "application/json");
			using HttpClient client = new HttpClient();
			if (JsonConvert.DeserializeObject<DiscordLoggerReply>((await client.PostAsync("http://derodeduivels.xyz/CrashLog", content)).Content.ReadAsStringAsync().Result) != null)
			{
				Console.WriteLine();
			}
		}
		catch
		{
		}
	}

	public static async void DebugReport()
	{
		try
		{
			if (string.IsNullOrEmpty(Settings.Default.alertWebhookUri))
			{
				return;
			}
			StringContent content = new StringContent(JsonConvert.SerializeObject(new
			{
				password = Xor.EncryptOrDecrypt("EtherealKey420"),
				username = Settings.Default.username,
				ProcessorId = HardWare.GetProcessorId(),
				GetHDDSerialNo = HardWare.GetHDDSerialNo(),
				GetMACAddress = HardWare.GetMACAddress(),
				GetBIOSmaker = HardWare.GetBIOSmaker(),
				GetBIOSserNo = HardWare.GetBIOSserNo(),
				GetOSInformation = HardWare.GetOSInformation(),
				GetComputerName = HardWare.GetComputerName()
			}).ToString(), Encoding.UTF8, "application/json");
			using HttpClient client = new HttpClient();
			if (JsonConvert.DeserializeObject<DiscordLoggerReply>((await client.PostAsync("http://derodeduivels.xyz/DebugReport", content)).Content.ReadAsStringAsync().Result) != null)
			{
				Console.WriteLine();
			}
		}
		catch
		{
		}
	}

	public static async void SendError(string title, string msg)
	{
		try
		{
			if (string.IsNullOrEmpty(Settings.Default.alertWebhookUri))
			{
				return;
			}
			StringContent content = new StringContent(JsonConvert.SerializeObject(new
			{
				password = Xor.EncryptOrDecrypt("EtherealKey420"),
				username = Settings.Default.username,
				title = title,
				message = msg
			}).ToString(), Encoding.UTF8, "application/json");
			using HttpClient client = new HttpClient();
			if (JsonConvert.DeserializeObject<DiscordLoggerReply>((await client.PostAsync("http://derodeduivels.xyz/ErrorAlert", content)).Content.ReadAsStringAsync().Result) != null)
			{
				Console.WriteLine();
			}
		}
		catch
		{
		}
	}

	public static async void SendLoggedIn()
	{
		try
		{
			if (string.IsNullOrEmpty(Settings.Default.loginWebhookUri))
			{
				return;
			}
			StringContent content = new StringContent(JsonConvert.SerializeObject(new
			{
				password = Xor.EncryptOrDecrypt("EtherealKey420"),
				username = Settings.Default.username,
				ProcessorId = HardWare.GetProcessorId(),
				GetHDDSerialNo = HardWare.GetHDDSerialNo(),
				GetMACAddress = HardWare.GetMACAddress(),
				GetBIOSmaker = HardWare.GetBIOSmaker(),
				GetBIOSserNo = HardWare.GetBIOSserNo(),
				GetOSInformation = HardWare.GetOSInformation(),
				GetComputerName = HardWare.GetComputerName()
			}).ToString(), Encoding.UTF8, "application/json");
			using HttpClient client = new HttpClient();
			if (JsonConvert.DeserializeObject<DiscordLoggerReply>((await client.PostAsync("http://derodeduivels.xyz/LoginAlert", content)).Content.ReadAsStringAsync().Result) != null)
			{
				Console.WriteLine();
			}
		}
		catch
		{
		}
	}
}
