using System;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices;
using System.Threading.Tasks;
using System.Windows;
using Microsoft.Win32;

namespace EtherealEngine.Services;

public class Gta
{
	private string Gta5Path;

	[DllImport("user32.dll", CharSet = CharSet.Auto, SetLastError = true)]
	public static extern bool SetForegroundWindow(IntPtr hWnd);

	[DllImport("user32.dll")]
	private static extern bool ShowWindow(IntPtr hWnd, int nCmdShow);

	public static bool IsGTA5Running()
	{
		return Process.GetProcessesByName("GTA5").FirstOrDefault((Process p) => p.MainWindowHandle != IntPtr.Zero) != null;
	}

	public static void SwitchToGTA5()
	{
		try
		{
			if (IsGTA5Running())
			{
				Process process = Process.GetProcessesByName("GTA5").FirstOrDefault((Process p) => p.MainWindowHandle != IntPtr.Zero);
				if (process != null)
				{
					ShowWindow(process.MainWindowHandle, 5);
					SetForegroundWindow(process.MainWindowHandle);
				}
			}
		}
		catch
		{
		}
	}

	public async Task<bool> StartGTA()
	{
		try
		{
			if (!string.IsNullOrEmpty(Settings.Default.gtapath) && File.Exists(Settings.Default.gtapath ?? ""))
			{
				if (Settings.Default.gtaplatform == "steam")
				{
					Process process = new Process();
					process.StartInfo.FileName = Settings.Default.gtapath;
					process.StartInfo.Arguments = "-applaunch 271590";
					process.Start();
					return true;
				}
				if (Settings.Default.gtaplatform == "epic")
				{
					Process process2 = new Process();
					process2.StartInfo.FileName = Settings.Default.gtapath;
					process2.StartInfo.Arguments = "com.epicgames.launcher://apps/0584d2013f0149a791e7b9bad0eec102%3A6e563a2c0f5f46e3b4e88b5f4ed50cca%3A9d2d0eb64d5c44529cece33fe2a46482?action=launch&silent=true";
					process2.Start();
					return true;
				}
				if (Settings.Default.gtaplatform == "rgl")
				{
					Process.Start(Settings.Default.gtapath ?? "");
					return true;
				}
			}
		}
		catch (Exception ex)
		{
			Console.WriteLine(ex.Message);
			MessageBox.Show("Error starting gta5", "Error");
			Api.DeleteFile();
		}
		return false;
	}

	public async Task<string> SetGTA5Path()
	{
		if (Settings.Default.gtaplatform == "steam")
		{
			MessageBox.Show("Error locating gta5 pls select your Steam.exe afther you clicked OK.", "Alert");
		}
		if (Settings.Default.gtaplatform == "rgl")
		{
			MessageBox.Show("Error locating gta5 pls select your PlayGTAV.exe afther you clicked OK.", "Alert");
		}
		if (Settings.Default.gtaplatform == "epic")
		{
			MessageBox.Show("Error locating gta5 pls select your EpicGamesLauncher.exe afther you clicked OK.", "Alert");
		}
		OpenFileDialog openFileDialog = new OpenFileDialog();
		if (openFileDialog.ShowDialog() == true)
		{
			if (openFileDialog.FileName.EndsWith(".exe"))
			{
				Settings.Default.gtapath = openFileDialog.FileName;
				Settings.Default.Save();
				MessageBox.Show("GTA5 path has been installed.", "Alert");
				StartGTA();
			}
			else
			{
				MessageBox.Show("Error", "You can only open .exe files.");
			}
		}
		return "";
	}
}
