using System;
using System.CodeDom.Compiler;
using System.ComponentModel;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Input;
using System.Windows.Markup;
using MaterialDesignThemes.Wpf;
using Newtonsoft.Json;

namespace EtherealEngine;

public class SettingsPage : Window, IComponentConnector
{
	internal Border DragOnHold;

	internal PackIcon CloseAppButton;

	internal Grid ToggleButtonsGrid;

	internal ToggleButton block_all_script_event;

	internal ToggleButton block_cage;

	internal ToggleButton block_clone;

	internal ToggleButton block_create;

	internal ToggleButton block_flood_create;

	internal ToggleButton block_invalid_sync_tree;

	internal ToggleButton block_invalid_vehicle_mod;

	internal ToggleButton block_net_array;

	internal ToggleButton block_net_event;

	internal ToggleButton block_object;

	internal ToggleButton block_object_model_crash;

	internal ToggleButton block_ped_model_crash;

	internal ToggleButton block_reward_crash;

	internal ToggleButton block_rope_collision_crash;

	internal ToggleButton block_script_event_crash;

	internal ToggleButton block_send_to_warehouse;

	internal ToggleButton block_sync;

	internal ToggleButton block_sync_bike;

	internal ToggleButton block_sync_door;

	internal ToggleButton block_sync_heli;

	internal ToggleButton block_sync_object;

	internal ToggleButton block_sync_ped;

	internal ToggleButton block_sync_pickup;

	internal ToggleButton block_sync_plane;

	internal ToggleButton block_sync_player;

	internal ToggleButton block_sync_submarine;

	internal ToggleButton block_sync_trailer;

	internal ToggleButton block_sync_train;

	internal ToggleButton block_sync_vehicle;

	internal ToggleButton block_text_message_spam;

	internal ToggleButton block_vehicle_model_crash;

	internal ToggleButton script_kick_and_crash;

	internal ToggleButton controller_support;

	internal ToggleButton crash_ad;

	internal ToggleButton script_host_kick_protection;

	internal ToggleButton model_crash;

	internal ToggleButton enable_modder_detection;

	internal ToggleButton bypass_spoof_name_detection;

	internal ToggleButton detect_explosive_ammo;

	internal ToggleButton detect_explosive_melee;

	internal ToggleButton detect_fire_ammo;

	internal ToggleButton detect_god_mode;

	internal ToggleButton detect_invalid_host_token;

	internal ToggleButton detect_invalid_scid;

	internal ToggleButton detect_melee_damage_mult;

	internal ToggleButton allow_use_weapon_indoor;

	internal ToggleButton ammo_track_npc;

	internal ToggleButton auto_force_script_host;

	internal ToggleButton beast_jump;

	internal ToggleButton auto_teleport_to_waypoint;

	internal ToggleButton kick_protection;

	internal ToggleButton no_ragdoll;

	internal ToggleButton god_mode;

	internal ToggleButton invisible;

	internal Button SaveSettings;

	private bool _contentLoaded;

	public SettingsPage()
	{
		InitializeComponent();
	}

	private void CloseAppButton_MouseDown(object sender, MouseButtonEventArgs e)
	{
		Close();
	}

	private void MinimizeButton_MouseDown(object sender, MouseButtonEventArgs e)
	{
		base.WindowState = WindowState.Minimized;
	}

	private void DragOnHold_MouseDown(object sender, MouseButtonEventArgs e)
	{
		try
		{
			if (e.ChangedButton == MouseButton.Left && e.LeftButton == MouseButtonState.Pressed)
			{
				DragMove();
			}
		}
		catch (Exception)
		{
		}
	}

	private void SaveSettings_Click(object sender, RoutedEventArgs e)
	{
		try
		{
			if (File.Exists("C:\\Ethereal\\settings.json"))
			{
				dynamic val = JsonConvert.DeserializeObject(File.ReadAllText("C:\\Ethereal\\settings.json"));
				foreach (ToggleButton item in ToggleButtonsGrid.Children.OfType<ToggleButton>())
				{
					val[item.Name] = item.IsChecked;
				}
				string contents = JsonConvert.SerializeObject(val, Formatting.Indented);
				File.WriteAllText("C:\\Ethereal\\settings.json", contents);
				Close();
			}
			else
			{
				MessageBox.Show("Could not find settings.js file", "Error");
				Close();
			}
		}
		catch (Exception)
		{
			MessageBox.Show("Failed to save settings", "Error");
			Close();
		}
	}

	private void Window_Loaded(object sender, RoutedEventArgs e)
	{
		try
		{
			if (File.Exists("C:\\Ethereal\\settings.json"))
			{
				dynamic val = JsonConvert.DeserializeObject(File.ReadAllText("C:\\Ethereal\\settings.json"));
				{
					foreach (ToggleButton item in ToggleButtonsGrid.Children.OfType<ToggleButton>())
					{
						item.IsChecked = val[item.Name];
					}
					return;
				}
			}
			MessageBox.Show("Could not find settings.js file", "Error");
			Close();
		}
		catch (Exception)
		{
			MessageBox.Show("Failed to read settings", "Error");
			Close();
		}
	}

	[DebuggerNonUserCode]
	[GeneratedCode("PresentationBuildTasks", "6.0.7.0")]
	public void InitializeComponent()
	{
		if (!_contentLoaded)
		{
			_contentLoaded = true;
			Uri resourceLocator = new Uri("/EtherealEngine;component/settingspage.xaml", UriKind.Relative);
			Application.LoadComponent(this, resourceLocator);
		}
	}

	[DebuggerNonUserCode]
	[GeneratedCode("PresentationBuildTasks", "6.0.7.0")]
	[EditorBrowsable(EditorBrowsableState.Never)]
	void IComponentConnector.Connect(int connectionId, object target)
	{
		switch (connectionId)
		{
		case 1:
			((SettingsPage)target).Loaded += Window_Loaded;
			break;
		case 2:
			DragOnHold = (Border)target;
			DragOnHold.MouseDown += DragOnHold_MouseDown;
			break;
		case 3:
			CloseAppButton = (PackIcon)target;
			CloseAppButton.MouseDown += CloseAppButton_MouseDown;
			break;
		case 4:
			ToggleButtonsGrid = (Grid)target;
			break;
		case 5:
			block_all_script_event = (ToggleButton)target;
			break;
		case 6:
			block_cage = (ToggleButton)target;
			break;
		case 7:
			block_clone = (ToggleButton)target;
			break;
		case 8:
			block_create = (ToggleButton)target;
			break;
		case 9:
			block_flood_create = (ToggleButton)target;
			break;
		case 10:
			block_invalid_sync_tree = (ToggleButton)target;
			break;
		case 11:
			block_invalid_vehicle_mod = (ToggleButton)target;
			break;
		case 12:
			block_net_array = (ToggleButton)target;
			break;
		case 13:
			block_net_event = (ToggleButton)target;
			break;
		case 14:
			block_object = (ToggleButton)target;
			break;
		case 15:
			block_object_model_crash = (ToggleButton)target;
			break;
		case 16:
			block_ped_model_crash = (ToggleButton)target;
			break;
		case 17:
			block_reward_crash = (ToggleButton)target;
			break;
		case 18:
			block_rope_collision_crash = (ToggleButton)target;
			break;
		case 19:
			block_script_event_crash = (ToggleButton)target;
			break;
		case 20:
			block_send_to_warehouse = (ToggleButton)target;
			break;
		case 21:
			block_sync = (ToggleButton)target;
			break;
		case 22:
			block_sync_bike = (ToggleButton)target;
			break;
		case 23:
			block_sync_door = (ToggleButton)target;
			break;
		case 24:
			block_sync_heli = (ToggleButton)target;
			break;
		case 25:
			block_sync_object = (ToggleButton)target;
			break;
		case 26:
			block_sync_ped = (ToggleButton)target;
			break;
		case 27:
			block_sync_pickup = (ToggleButton)target;
			break;
		case 28:
			block_sync_plane = (ToggleButton)target;
			break;
		case 29:
			block_sync_player = (ToggleButton)target;
			break;
		case 30:
			block_sync_submarine = (ToggleButton)target;
			break;
		case 31:
			block_sync_trailer = (ToggleButton)target;
			break;
		case 32:
			block_sync_train = (ToggleButton)target;
			break;
		case 33:
			block_sync_vehicle = (ToggleButton)target;
			break;
		case 34:
			block_text_message_spam = (ToggleButton)target;
			break;
		case 35:
			block_vehicle_model_crash = (ToggleButton)target;
			break;
		case 36:
			script_kick_and_crash = (ToggleButton)target;
			break;
		case 37:
			controller_support = (ToggleButton)target;
			break;
		case 38:
			crash_ad = (ToggleButton)target;
			break;
		case 39:
			script_host_kick_protection = (ToggleButton)target;
			break;
		case 40:
			model_crash = (ToggleButton)target;
			break;
		case 41:
			enable_modder_detection = (ToggleButton)target;
			break;
		case 42:
			bypass_spoof_name_detection = (ToggleButton)target;
			break;
		case 43:
			detect_explosive_ammo = (ToggleButton)target;
			break;
		case 44:
			detect_explosive_melee = (ToggleButton)target;
			break;
		case 45:
			detect_fire_ammo = (ToggleButton)target;
			break;
		case 46:
			detect_god_mode = (ToggleButton)target;
			break;
		case 47:
			detect_invalid_host_token = (ToggleButton)target;
			break;
		case 48:
			detect_invalid_scid = (ToggleButton)target;
			break;
		case 49:
			detect_melee_damage_mult = (ToggleButton)target;
			break;
		case 50:
			allow_use_weapon_indoor = (ToggleButton)target;
			break;
		case 51:
			ammo_track_npc = (ToggleButton)target;
			break;
		case 52:
			auto_force_script_host = (ToggleButton)target;
			break;
		case 53:
			beast_jump = (ToggleButton)target;
			break;
		case 54:
			auto_teleport_to_waypoint = (ToggleButton)target;
			break;
		case 55:
			kick_protection = (ToggleButton)target;
			break;
		case 56:
			no_ragdoll = (ToggleButton)target;
			break;
		case 57:
			god_mode = (ToggleButton)target;
			break;
		case 58:
			invisible = (ToggleButton)target;
			break;
		case 59:
			SaveSettings = (Button)target;
			SaveSettings.Click += SaveSettings_Click;
			break;
		default:
			_contentLoaded = true;
			break;
		}
	}
}
